@@ -1089,10 +1089,24 @@ def ProcessCommandLine(cmdline_list):
     "remove-old", "restore", "verify", "full", or "inc".
 
     """
+    # build initial gpg_profile
     globals.gpg_profile = gpg.GPGProfile()
 
+    # parse command line
     args = parse_cmdline_options(cmdline_list)
 
+    # if we get a different gpg-binary from the commandline then redo gpg_profile
+    if globals.gpg_binary is not None:
+        src = globals.gpg_profile
+        globals.gpg_profile = gpg.GPGProfile(
+            passphrase=src.passphrase,
+            sign_key=src.sign_key,
+            recipients=src.recipients,
+            hidden_recipients=src.hidden_recipients)
+    log.Debug(_("GPG binary is %s, version %s") %
+              ((globals.gpg_binary or 'gpg'),
+               "%d.%d.%d" % globals.gpg_profile.gpg_version))
+
     # we can now try to import all the backends
     backend.import_backends()
 
